# Changelog

<!--next-version-placeholder-->

## v0.13.2 (2023-03-07)
### Fix
* Handle jsondecode error ([#100](https://github.com/harvey251/pydantic-lambda-handler/issues/100)) ([`00044de`](https://github.com/harvey251/pydantic-lambda-handler/commit/00044de03f88b4087816ce65cf55b3da561314fa))

## v0.13.1 (2023-03-07)
### Fix
* Avoid json decode error if no body, ([#98](https://github.com/harvey251/pydantic-lambda-handler/issues/98)) ([`99cf781`](https://github.com/harvey251/pydantic-lambda-handler/commit/99cf7812d6ded98fb41472e8b397b8f5e0c8f9eb))

## v0.13.0 (2023-02-15)
### Feature
* Add the base url ([#96](https://github.com/harvey251/pydantic-lambda-handler/issues/96)) ([`ee7fc60`](https://github.com/harvey251/pydantic-lambda-handler/commit/ee7fc6081016a86419ec54ea4f72353aee011c2d))

## v0.12.8 (2023-01-31)
### Fix
* Add strings for ordering the hooks ([#95](https://github.com/harvey251/pydantic-lambda-handler/issues/95)) ([`e5f5c12`](https://github.com/harvey251/pydantic-lambda-handler/commit/e5f5c12a26454e1779c5ba1ee03bc9f042d40eff))

## v0.12.7 (2023-01-31)
### Fix
* Add pre return hook ([#94](https://github.com/harvey251/pydantic-lambda-handler/issues/94)) ([`19f889c`](https://github.com/harvey251/pydantic-lambda-handler/commit/19f889cd5a1623ab6a103a43e36c857eeac46194))

## v0.12.6 (2022-12-06)
### Fix
* Add info about openapi-spec-validator to docs ([#93](https://github.com/harvey251/pydantic-lambda-handler/issues/93)) ([`bbbbe11`](https://github.com/harvey251/pydantic-lambda-handler/commit/bbbbe11047a8c98a280633d785754f9be53c74a6))

## v0.12.5 (2022-12-06)
### Fix
* Add open api spec validation ([#92](https://github.com/harvey251/pydantic-lambda-handler/issues/92)) ([`0f1dc70`](https://github.com/harvey251/pydantic-lambda-handler/commit/0f1dc704f2bd031f19000a46fb4aed54a693786d))

## v0.12.4 (2022-11-09)
### Fix
* Add unions ([#91](https://github.com/harvey251/pydantic-lambda-handler/issues/91)) ([`5e0fd90`](https://github.com/harvey251/pydantic-lambda-handler/commit/5e0fd90d51a5fd24bae0342bb1d3374057141200))

## v0.12.3 (2022-11-02)
### Fix
* Add docs for path parameters ([#86](https://github.com/harvey251/pydantic-lambda-handler/issues/86)) ([`90c053e`](https://github.com/harvey251/pydantic-lambda-handler/commit/90c053ee6175299f798deece40767faff5501dc4))

## v0.12.2 (2022-11-02)
### Fix
* Allow parsing of standard default types ([#85](https://github.com/harvey251/pydantic-lambda-handler/issues/85)) ([`90d12ff`](https://github.com/harvey251/pydantic-lambda-handler/commit/90d12fff7380097c7e0f4ebcc91887f98d294f74))

## v0.12.1 (2022-11-02)
### Fix
* Add error handling docs ([#84](https://github.com/harvey251/pydantic-lambda-handler/issues/84)) ([`123c543`](https://github.com/harvey251/pydantic-lambda-handler/commit/123c54325a73f3153973a1ae3d39b871d9ffdbcd))

## v0.12.0 (2022-11-02)
### Feature
* Add error handling ([#83](https://github.com/harvey251/pydantic-lambda-handler/issues/83)) ([`2aaa550`](https://github.com/harvey251/pydantic-lambda-handler/commit/2aaa55078e78accf9ce27cc6b491bd940013103e))

## v0.11.1 (2022-10-25)
### Fix
* Add docs for query headers ([`5d6d741`](https://github.com/harvey251/pydantic-lambda-handler/commit/5d6d7418488d9d576c3c338aedb7c1496b8063df))

## v0.11.0 (2022-10-25)
### Feature
* Multi Value Query model ([#79](https://github.com/harvey251/pydantic-lambda-handler/issues/79)) ([`44c4920`](https://github.com/harvey251/pydantic-lambda-handler/commit/44c4920c64c5f6dcc5364eeb11bb08f32fcfb5db))

## v0.10.2 (2022-10-11)
### Fix
* Add docs for headers and context ([#77](https://github.com/harvey251/pydantic-lambda-handler/issues/77)) ([`53da543`](https://github.com/harvey251/pydantic-lambda-handler/commit/53da543b59508a3e369d12af08265cda50d61802))

## v0.10.1 (2022-10-11)
### Fix
* Bug with cdk conf ([#76](https://github.com/harvey251/pydantic-lambda-handler/issues/76)) ([`1c5657b`](https://github.com/harvey251/pydantic-lambda-handler/commit/1c5657baa59ae31a7149bf76d504b11ab0d77e10))

## v0.10.0 (2022-10-03)
### Feature
* Add headers ([#75](https://github.com/harvey251/pydantic-lambda-handler/issues/75)) ([`979d7ff`](https://github.com/harvey251/pydantic-lambda-handler/commit/979d7ffa27c485577dad2c107409d620750fa0a6))

## v0.9.0 (2022-09-27)
### Feature
* Add handlers folder ([#73](https://github.com/harvey251/pydantic-lambda-handler/issues/73)) ([`e41a6b9`](https://github.com/harvey251/pydantic-lambda-handler/commit/e41a6b9b36c99c147faa1636ef0e9396408b69cf))

## v0.8.11 (2022-09-24)
### Fix
* Capture error for mock requests ([#72](https://github.com/harvey251/pydantic-lambda-handler/issues/72)) ([`ca961da`](https://github.com/harvey251/pydantic-lambda-handler/commit/ca961da9f618b537950edab9ec58b3949ce50f3f))

## v0.8.10 (2022-09-21)
### Fix
* Set event body as optional ([#70](https://github.com/harvey251/pydantic-lambda-handler/issues/70)) ([`7d7ee58`](https://github.com/harvey251/pydantic-lambda-handler/commit/7d7ee58cae07fee08cc2a696a07570f389e649bb))

## v0.8.9 (2022-09-21)
### Fix
* Allow "name" not to be set in conf ([#69](https://github.com/harvey251/pydantic-lambda-handler/issues/69)) ([`67bb4e4`](https://github.com/harvey251/pydantic-lambda-handler/commit/67bb4e4a514b0d1ca69bd7b31f978e691ce6f971))

## v0.8.8 (2022-09-07)
### Fix
* Run checks in ci ([#66](https://github.com/harvey251/pydantic-lambda-handler/issues/66)) ([`17f78c6`](https://github.com/harvey251/pydantic-lambda-handler/commit/17f78c6a986446114ecd44779f0c6c6461273d53))

## v0.8.7 (2022-09-07)
### Fix
* Add index location and remove prints ([#65](https://github.com/harvey251/pydantic-lambda-handler/issues/65)) ([`00abacc`](https://github.com/harvey251/pydantic-lambda-handler/commit/00abacc35ccbfbcd12d00dbec8c2d38c89d9abd5))

## v0.8.6 (2022-09-05)
### Fix
* Add generate_event ([#64](https://github.com/harvey251/pydantic-lambda-handler/issues/64)) ([`26e026f`](https://github.com/harvey251/pydantic-lambda-handler/commit/26e026f9440e07b5d4d34c240dafc9abf9f4c144))

## v0.8.5 (2022-09-05)
### Fix
* Use response model ([#63](https://github.com/harvey251/pydantic-lambda-handler/issues/63)) ([`ad3b17c`](https://github.com/harvey251/pydantic-lambda-handler/commit/ad3b17c1f326dd7e9bf8153d3dc19a65d07bdd61))

## v0.8.4 (2022-09-01)
### Fix
* Add debug logs ([#62](https://github.com/harvey251/pydantic-lambda-handler/issues/62)) ([`e8ddaaf`](https://github.com/harvey251/pydantic-lambda-handler/commit/e8ddaaf8a12fc2577784dfa4b4f970abdc2fbce3))

## v0.8.3 (2022-08-31)
### Fix
* Add logging on error ([#61](https://github.com/harvey251/pydantic-lambda-handler/issues/61)) ([`4e65733`](https://github.com/harvey251/pydantic-lambda-handler/commit/4e65733bb0d54111127c7bde23d4abf102ec6aa8))

## v0.8.2 (2022-08-30)
### Fix
* Add pypi repo details ([#58](https://github.com/harvey251/pydantic-lambda-handler/issues/58)) ([`4af957f`](https://github.com/harvey251/pydantic-lambda-handler/commit/4af957fac980ec1b9dc063ef5933582e609001d2))

## v0.8.1 (2022-08-30)
### Fix
* Allow list response ([#57](https://github.com/harvey251/pydantic-lambda-handler/issues/57)) ([`8045667`](https://github.com/harvey251/pydantic-lambda-handler/commit/80456671d322374c6aeb45121afa8372ed184e22))

## v0.6.3 (2022-08-15)
### Fix
* Add a space ([`fd182ac`](https://github.com/harvey251/pydantic-lambda-handler/commit/fd182acd14017b320d480a5cb8b7a6218501ac42))

## v0.6.2 (2022-08-15)
### Fix
* Add a space ([`fd182ac`](https://github.com/harvey251/pydantic-lambda-handler/commit/fd182acd14017b320d480a5cb8b7a6218501ac42))
* Add a space ([`1cb8651`](https://github.com/harvey251/pydantic-lambda-handler/commit/1cb8651e67a116ff4e164bda94168dbd64ac620e))

## v0.6.1 (2022-08-15)
### Fix
* Add a space ([`8e4a006`](https://github.com/harvey251/pydantic-lambda-handler/commit/8e4a0066e649aa7ea126e9ce9ba53cee3709b46f))

## v0.6.0 (2022-08-15)
### Feature
* Add request body to open api spec ([#35](https://github.com/harvey251/pydantic-lambda-handler/issues/35)) ([`47891da`](https://github.com/harvey251/pydantic-lambda-handler/commit/47891da9ec80bfe312dc8489b2565333f9e9ba3b))

## v0.5.1 (2022-08-14)
### Fix
* Merge post and get ([#33](https://github.com/harvey251/pydantic-lambda-handler/issues/33)) ([`f4cff6f`](https://github.com/harvey251/pydantic-lambda-handler/commit/f4cff6f68ad1185f120cbd542aa946cf128a6a75))

## v0.5.0 (2022-08-14)
### Feature
* Add post data ([#32](https://github.com/harvey251/pydantic-lambda-handler/issues/32)) ([`544b1e1`](https://github.com/harvey251/pydantic-lambda-handler/commit/544b1e16882de23c6ddd9d791dc7255ac9d46650))

## v0.4.1 (2022-08-12)
### Fix
* Add pydantic core test ([#31](https://github.com/harvey251/pydantic-lambda-handler/issues/31)) ([`368deae`](https://github.com/harvey251/pydantic-lambda-handler/commit/368deae1976862a975bafaf23b18333e1ac3b68a))

## v0.4.0 (2022-08-12)
### Feature
* Add query ([#30](https://github.com/harvey251/pydantic-lambda-handler/issues/30)) ([`fcfa161`](https://github.com/harvey251/pydantic-lambda-handler/commit/fcfa161d73cf78de5716a3449ac3ac33a84908c2))

## v0.3.1 (2022-08-11)
### Fix
* Add check for redeclaration of path ([#29](https://github.com/harvey251/pydantic-lambda-handler/issues/29)) ([`a9671c6`](https://github.com/harvey251/pydantic-lambda-handler/commit/a9671c6f4c5ca6d61032e6ebbed986df3dae536b))

## v0.3.0 (2022-08-11)
### Feature
* Move gen open api spec into a hook ([#28](https://github.com/harvey251/pydantic-lambda-handler/issues/28)) ([`a2e34b8`](https://github.com/harvey251/pydantic-lambda-handler/commit/a2e34b8736a6303009a7d8ea64cefa2afd3a915a))

## v0.2.0 (2022-07-31)
### Feature
* Add task to deploy ([#23](https://github.com/harvey251/pydantic-lambda-handler/issues/23)) ([`ea67f71`](https://github.com/harvey251/pydantic-lambda-handler/commit/ea67f71001552b4eeff8d08a9379c7e271be7921))

### Documentation
* Improve Vision statement ([#22](https://github.com/harvey251/pydantic-lambda-handler/issues/22)) ([`af7c95f`](https://github.com/harvey251/pydantic-lambda-handler/commit/af7c95f73b3d71b56948b50ddacf5aaa52e7ebd7))

## v0.1.0 (2022-07-13)
### Feature
* Add open api spec ([`a6b5ff9`](https://github.com/harvey251/pydantic-lambda-handler/commit/a6b5ff96bf4695c6dd9ee2e73492a97134323361))
* Add error message with invalid params ([#8](https://github.com/harvey251/pydantic-lambda-handler/issues/8)) ([`0ad9ff1`](https://github.com/harvey251/pydantic-lambda-handler/commit/0ad9ff13e512a0904624a8f806cb787393040650))
* Add open api spec ([#7](https://github.com/harvey251/pydantic-lambda-handler/issues/7)) ([`82db24b`](https://github.com/harvey251/pydantic-lambda-handler/commit/82db24b23025939188ee6ed728bbc31d28552124))

### Fix
* Release on main ([#12](https://github.com/harvey251/pydantic-lambda-handler/issues/12)) ([`c142360`](https://github.com/harvey251/pydantic-lambda-handler/commit/c142360be3c88a568969625ae5c08d7daf83b8ba))
* Add default required values for open api spec ([#11](https://github.com/harvey251/pydantic-lambda-handler/issues/11)) ([`e380eb9`](https://github.com/harvey251/pydantic-lambda-handler/commit/e380eb90ce5c3a21b9790742497ec88a8805ad40))
* Add init ([#10](https://github.com/harvey251/pydantic-lambda-handler/issues/10)) ([`c20f3bb`](https://github.com/harvey251/pydantic-lambda-handler/commit/c20f3bb437e9ac38e4e50c89981c32afbd44aedb))
